@@ -1,14 +1,13 @@
 import pygame;
 from abc import ABC, abstractmethod
 from os.path import exists as file_exists;
+from typing import overload
 from pygame.surface import Surface
 from pygame.locals import (RLEACCEL);
 
-from multimethod import multimethod
-
-from dna_engine.dna_engine.game import Game
-from dna_engine.dna_engine.world import World
-from dna_engine.dna_engine.tilemaps.tile import Tile
+from dna_engine.game import Game
+from dna_engine.world import World
+from dna_engine.tilemaps.tile import Tile
 
 class Actor(ABC):
     """
@@ -29,6 +28,7 @@ class Actor(ABC):
         self.__rect = self.__sprite.get_rect()
         self.__raw_image = self.__sprite
         self.__game = None
+        self.__position = pygame.Vector2(0, 0)
         self.__rotation = 0
         self.__scale = 1.0
         self.__visible = True
@@ -91,7 +91,8 @@ class Actor(ABC):
         :return: A floating-point value representing the horizontal location of this Actor.
         :rtype: float
         """
-        return self.__rect.centerx
+        return self.__position[0]
+        #return self.__rect.centerx
 
 
     def get_y(self) -> float:
@@ -101,7 +102,8 @@ class Actor(ABC):
         :return: A floating-point value representing the vertical location of this Actor.
         :rtype: float
         """
-        return self.__rect.centery
+        return self.__position[1]
+        #return self.__rect.centery
     
 
     def get_width(self) -> float:
@@ -222,23 +224,9 @@ class Actor(ABC):
             return hit
         
         return None
-
-
-    @multimethod
-    def move(self, move_by_x : float, move_by_y : float) -> None:
-        """
-        Moves this Actor by the given amount.
-
-        :param move_by_x: The x-axis (horizontal) number of pixels to move by.
-        :type move_by_x: float
-
-        :param move_by_y: The y-axis (vertical) number of pixels to move by.
-        :type move_by_y: float
-        """
-        self.__rect.move_ip(move_by_x, move_by_y);
     
 
-    @multimethod
+    @overload
     def move(self, move_by : pygame.Vector2) -> None:
         """
         [Overload] Moves this Actor by the given amount.
@@ -249,7 +237,7 @@ class Actor(ABC):
         self.move(move_by[0], move_by[1])
 
 
-    @multimethod
+    @overload
     def move(self, move_by_x : int, move_by_y : int) -> None:
         """
         [Overload] Moves this Actor by the given amount.
@@ -262,7 +250,44 @@ class Actor(ABC):
         self.move(float(move_by_x), float(move_by_y))
 
 
-    @multimethod
+    def move(self, move_by_x : float, move_by_y : float) -> None:
+        """
+        Moves this Actor by the given amount.
+
+        :param move_by_x: The x-axis (horizontal) number of pixels to move by.
+        :type move_by_x: float
+
+        :param move_by_y: The y-axis (vertical) number of pixels to move by.
+        :type move_by_y: float
+        """
+        self.__rect.move_ip(move_by_x, move_by_y);
+        self.__position = self.__rect.center
+    
+
+    @overload
+    def set_position(self, new_x : int, new_y : int) -> None:
+        """
+        [Overload] Sets the on-screen location of this Actor to the given co-ordinates.
+
+        :param new_x: The horizontal (x-axis) co-ordinate of the desired new location.
+        :type new_x: int
+        :param new_y: The vertical (y-axis) co-ordinate of the desired new location.
+        :type new_y: int
+        """
+        self.set_position(float(new_x), float(new_y))
+    
+
+    @overload
+    def set_position(self, new_position : pygame.Vector2) -> None:
+        """
+        [Overload] Sets the on-screen location of this Actor to the given co-ordinates.
+
+        :param new_position: The x and y-axis co-ordinates this Actor should be set to.
+        :type new_position: pygame.Vector2
+        """
+        self.set_position(new_position[0], new_position[1])
+    
+
     def set_position(self, new_x : float, new_y : float) -> None:
         """
         Sets the on-screen location of this Actor to the given co-ordinates.
@@ -273,19 +298,8 @@ class Actor(ABC):
         :param new_y: The vertical (y-axis) co-ordinate of the desired new location.
         :type new_y: float
         """
-        self.__rect.centerx = new_x;
-        self.__rect.centery = new_y;
-    
-
-    @multimethod
-    def set_position(self, new_position : pygame.Vector2) -> None:
-        """
-        [Overload] Sets the on-screen location of this Actor to the given co-ordinates.
-
-        :param new_position: The x and y-axis co-ordinates this Actor should be set to.
-        :type new_position: pygame.Vector2
-        """
-        self.set_position(new_position[0], new_position[1])
+        self.__position = pygame.Vector2(new_x, new_y)
+        self.__rect.center = self.__position
     
 
     def get_position(self) -> pygame.Vector2:
@@ -382,6 +396,7 @@ class Actor(ABC):
     def __generate_sprite(self):
         self.__sprite = pygame.transform.rotozoom(self.__raw_image, self.__rotation, self.__scale)
         self.__rect = self.__sprite.get_rect(center=self.__rect.center)
+        self.__rect.center = self.__position
 
 
     def is_visible(self) -> bool:
